/*
 * @(#)ProblemSetClass.java  1.0  4 March 2002
 *
 * Copyright 2001
 * College of Computer Science
 * Northeastern University
 * Boston, MA  02115
 *
 * This software may be used for educational purposes as long as
 * this copyright notice is retained intact at the top of all files.
 *
 * Should this software be modified, the words "Modified from 
 * Original" must be included as a comment below this notice.
 *
 * All publication rights are retained.  This software or its 
 * documentation may not be published in any media either in whole
 * or in part without explicit permission.
 *
 * Contact information:
 *   Richard Rasala    rasala@ccs.neu.edu
 *   Viera Proulx      vkp@ccs.neu.edu
 *   Jeff Raab         jmr@ccs.neu.edu
 * 
 * Telephone:          617-373-2462
 *
 * This software was created with support from Northeastern 
 * University and from NSF grant DUE-9950829.
 */

import edu.neu.ccs.*;
import edu.neu.ccs.gui.*;
import edu.neu.ccs.util.*;
import edu.neu.ccs.filter.*;
import edu.neu.ccs.console.*;
import edu.neu.ccs.pedagogy.*;

import java.awt.*;
import java.awt.event.*;
import java.awt.geom.*;
import java.util.*;
import javax.swing.*;
import java.lang.reflect.*;

/**
 * This class provides a setting for creating a problem set
 * with access to the JPT console I/O and simple graphics
 * via a BufferedPanel.  The member functions in this class
 * that are public synchronized void with zero arguments but
 * not static will be put into actions that are activated by
 * buttons in the GUI.
 */
public class ProblemSetClass
    implements JPTConstants, ConsoleAware
{
    /** The parent problem set application. */
    protected ProblemSetApplication application = null;
    
    /** The graphics buffered panel. */
    protected BufferedPanel window = null;
    
    /** The optional large GUI panel between the buttons and the graphics. */
    protected DisplayPanel largeGUIPanel = null;
    
    /** The optional small GUI panel below the buttons. */
    protected DisplayPanel smallGUIPanel = null;
    
    /** Change this title if you desire a special frame title. */
    public final String title = null;
    
    /** If true, show console. */
    public final boolean showConsoleWindow  = true;
    
    /** If true, show graphics window. */
    public final boolean showGraphicsWindow = true;
    
    /////////////////
    // Constructor //
    /////////////////
    
    /** The constructor invoked by the ProblemSetApplication. */
    public ProblemSetClass(ProblemSetApplication application) {
        this.application = application;
        
        if (application != null)
            window = application.getGraphicsWindow();
    }
    
    ///////////////////////////////////////////////////////////
    // A method will generate an action button in the GUI if //
    // it is public synchronized void with zero arguments    //
    // but not static.                                       //
    //                                                       //
    // Place these methods here.                             //
    ///////////////////////////////////////////////////////////
    
    public synchronized void SimpleFibonacci() {
        console.out.println("SimpleFibonacci\n");
        XInt N = new XInt();
    
        while (console.in.reading("Enter n:", N)) {
            int n = N.getValue();
            double value = FibonacciSamples.SimpleFibonacci(n);
            console.out.println("SimpleFibonacci: " + value + "\n");
        }
        
        console.out.println();
    }
    
    public synchronized void LoopFibonacci() {
        console.out.println("LoopFibonacci\n");
        XInt N = new XInt();
    
        while (console.in.reading("Enter n:", N)) {
            int n = N.getValue();
            double value = FibonacciSamples.LoopFibonacci(n);
            console.out.println("LoopFibonacci: " + value + "\n");
        }
        
        console.out.println();
    }
    
    public synchronized void SubtleFibonacci() {
        console.out.println("SubtleFibonacci\n");
        XInt N = new XInt();
    
        while (console.in.reading("Enter n:", N)) {
            int n = N.getValue();
            double value = FibonacciSamples.SubtleFibonacci(n);
            console.out.println("SubtleFibonacci: " + value + "\n");
        }
        
        console.out.println();
    }
    
    public synchronized void FancyFibonacci() {
        console.out.println("FancyFibonacci\n");
        XInt N = new XInt();
    
        while (console.in.reading("Enter n:", N)) {
            int n = N.getValue();
            double value = FibonacciSamples.FancyFibonacci(n);
            console.out.println("FancyFibonacci: " + value + "\n");
        }
        
        console.out.println();
    }
    
}

